@@ -2506,6 +2506,20 @@ int perl_png_libpng_supports (const char * what)
         return 0;
 #endif /* tRNS */
     }
+    if (strcmp (what, "WRITE_CUSTOMIZE_ZTXT_COMPRESSION") == 0) {
+#ifdef PNG_WRITE_CUSTOMIZE_ZTXT_COMPRESSION_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* WRITE_CUSTOMIZE_ZTXT_COMPRESSION */
+    }
+    if (strcmp (what, "WRITE_CUSTOMIZE_COMPRESSION") == 0) {
+#ifdef PNG_WRITE_CUSTOMIZE_COMPRESSION_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* WRITE_CUSTOMIZE_COMPRESSION */
+    }
 #line 2343 "perl-libpng.c.tmpl"
 
     /* sCAL is a special case. */
@@ -2612,7 +2626,7 @@ static SV * perl_png_get_cHRM (perl_libpng_t * png)
 #ifdef PNG_cHRM_SUPPORTED
     if (VALID (cHRM)) {
         HV * ice;
-#line 2615 "/usr/home/ben/projects/image-png-libpng/build/../perl-libpng.c"
+#line 2629 "/usr/home/ben/projects/image-png-libpng/build/../perl-libpng.c"
         double white_x;
         double white_y;
         double red_x;
@@ -2624,7 +2638,7 @@ static SV * perl_png_get_cHRM (perl_libpng_t * png)
 #line 2453 "perl-libpng.c.tmpl"
         png_get_cHRM (pngi , & white_x, & white_y, & red_x, & red_y, & green_x, & green_y, & blue_x, & blue_y);
         ice = newHV ();
-#line 2627 "/usr/home/ben/projects/image-png-libpng/build/../perl-libpng.c"
+#line 2641 "/usr/home/ben/projects/image-png-libpng/build/../perl-libpng.c"
         (void) hv_store (ice, "white_x", strlen ("white_x"),
                          newSVnv (white_x), 0);
         (void) hv_store (ice, "white_y", strlen ("white_y"),
@@ -2656,7 +2670,7 @@ static void perl_png_set_cHRM (perl_libpng_t * png, HV * cHRM)
 {
 #ifdef PNG_cHRM_SUPPORTED
     SV ** key_sv_ptr;
-#line 2659 "/usr/home/ben/projects/image-png-libpng/build/../perl-libpng.c"
+#line 2673 "/usr/home/ben/projects/image-png-libpng/build/../perl-libpng.c"
     double white_x = 0.0;
     double white_y = 0.0;
     double red_x = 0.0;
@@ -2733,7 +2747,7 @@ static void perl_png_copy_row_pointers (perl_libpng_t * png, SV * row_pointers)
     png_set_rows (pngi, png->row_pointers);
 }
 
-#line 2736 "/usr/home/ben/projects/image-png-libpng/build/../perl-libpng.c"
+#line 2750 "/usr/home/ben/projects/image-png-libpng/build/../perl-libpng.c"
 
 static int
 perl_png_get_image_width (perl_libpng_t * png)
